@@ -74,14 +74,14 @@ pub fn derive_struct_traits(input: proc_macro::TokenStream) -> proc_macro::Token
     let name = format_token!("{}", syn::parse_macro_input!(input as syn::DeriveInput).ident.to_string());
 
     let tokens = quote! {
-        impl ::std::cmp::PartialEq for #name {
+        impl ::core::cmp::PartialEq for #name {
             fn eq(&self, other: &Self) -> bool {
                 unsafe {
-                    ::windows::runtime::memcmp(self as *const _ as _, other as *const _ as _, std::mem::size_of::<#name>()) == 0
+                    ::windows::runtime::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<#name>()) == 0
                 }
             }
         }
-        impl ::std::cmp::Eq for #name {}
+        impl ::core::cmp::Eq for #name {}
     };
 
     tokens.as_str().parse().unwrap()
